# Table of Contents

- [discovering-ai-agents-from-microsoft-entra-id](<./discovering-ai-agents-from-microsoft-entra-id.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Discovering AI Agents from Microsoft Entra ID](<./Discovering-AI-Agents-from-Microsoft-Entra-ID.md>)
  - [Overview](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Overview.md>)
  - [Scope](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Scope.md>)
  - [Prerequisites](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Prerequisites.md>)
  - [Step 1: Register SAP LeanIX in Microsoft Entra ID](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Step-1-Register-SAP-LeanIX-in-Microsoft-Entra-ID.md>)
  - [Step 2: Grant Permissions to SAP LeanIX](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Step-2-Grant-Permissions-to-SAP-LeanIX.md>)
  - [Step 3: Gather Configuration Credentials](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Step-3-Gather-Configuration-Credentials.md>)
  - [Step 4: Connect SAP LeanIX to Microsoft Entra ID](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Step-4-Connect-SAP-LeanIX-to-Microsoft-Entra-ID.md>)
  - [Linking Discovered Items to Fact Sheets](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Viewing-Synchronization-Logs.md>)
  - [Was this page helpful?](<./Discovering-AI-Agents-from-Microsoft-Entra-ID/Was-this-page-helpful.md>)
